<?php

namespace Bixo\Developers\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bixo\Developers\Models\Developers;

class DevelopersPolicy
{

    /**
     * Determine if the given user can view the developers.
     *
     * @param UserPolicy $user
     * @param Developers $developers
     *
     * @return bool
     */
    public function view(UserPolicy $user, Developers $developers)
    {
        if ($user->canDo('developers.developers.view') && $user->isAdmin()) {
            return true;
        }

        return $developers->user_id == user_id() && $developers->user_type == user_type();
    }

    /**
     * Determine if the given user can create a developers.
     *
     * @param UserPolicy $user
     * @param Developers $developers
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('developers.developers.create');
    }

    /**
     * Determine if the given user can update the given developers.
     *
     * @param UserPolicy $user
     * @param Developers $developers
     *
     * @return bool
     */
    public function update(UserPolicy $user, Developers $developers)
    {
        if ($user->canDo('developers.developers.edit') && $user->isAdmin()) {
            return true;
        }

        return $developers->user_id == user_id() && $developers->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given developers.
     *
     * @param UserPolicy $user
     * @param Developers $developers
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Developers $developers)
    {
        return $developers->user_id == user_id() && $developers->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given developers.
     *
     * @param UserPolicy $user
     * @param Developers $developers
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Developers $developers)
    {
        if ($user->canDo('developers.developers.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given developers.
     *
     * @param UserPolicy $user
     * @param Developers $developers
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Developers $developers)
    {
        if ($user->canDo('developers.developers.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
